@@ -20,7 +20,7 @@ interface LargeLoaderProps {
 export const LargeLoader: React.FC<LargeLoaderProps> = ({ text }) => {
     return (
         <div className="mx_LargeLoader">
-            <Spinner w={45} h={45} />
+            <Spinner size={45} />
             <div className="mx_LargeLoader_text">{text}</div>
         </div>
     );
