@@ -40,6 +40,7 @@ import classNames from "classnames";
 import { sortBy, uniqBy } from "lodash";
 import { logger } from "matrix-js-sdk/src/logger";
 import { KnownMembership, type SpaceChildEventContent } from "matrix-js-sdk/src/types";
+import { ChevronDownIcon, CheckIcon } from "@vector-im/compound-design-tokens/assets/web/icons";
 
 import defaultDispatcher from "../../dispatcher/dispatcher";
 import { _t } from "../../languageHandler";
@@ -149,7 +150,7 @@ const Tile: React.FC<ITileProps> = ({
                 tabIndex={isActive ? 0 : -1}
                 title={_t("space|joining_space")}
             >
-                <Spinner w={24} h={24} />
+                <Spinner size={24} />
             </AccessibleButton>
         );
     } else if (joinedRoom || room.join_rule === JoinRule.Knock) {
@@ -251,7 +252,12 @@ const Tile: React.FC<ITileProps> = ({
 
     let joinedSection: ReactElement | undefined;
     if (joinedRoom) {
-        joinedSection = <div className="mx_SpaceHierarchy_roomTile_joined">{_t("common|joined")}</div>;
+        joinedSection = (
+            <div className="mx_SpaceHierarchy_roomTile_joined">
+                <CheckIcon />
+                {_t("common|joined")}
+            </div>
+        );
     }
 
     let suggestedSection: ReactElement | undefined;
@@ -294,7 +300,9 @@ const Tile: React.FC<ITileProps> = ({
                     ev.stopPropagation();
                     toggleShowChildren();
                 }}
-            />
+            >
+                <ChevronDownIcon />
+            </div>
         );
 
         if (showChildren) {
