@@ -10,6 +10,12 @@ import { EventType, RoomType, JoinRule, Preset, type Room, RoomEvent } from "mat
 import { KnownMembership } from "matrix-js-sdk/src/types";
 import { logger } from "matrix-js-sdk/src/logger";
 import React, { type JSX, useCallback, useContext, useRef, useState } from "react";
+import {
+    GroupIcon,
+    PlusIcon,
+    RoomIcon,
+    UserProfileSolidIcon,
+} from "@vector-im/compound-design-tokens/assets/web/icons";
 
 import MatrixClientContext from "../../contexts/MatrixClientContext";
 import createRoom, { type IOpts } from "../../createRoom";
@@ -66,6 +72,8 @@ import MainSplit from "./MainSplit";
 import RightPanel from "./RightPanel";
 import SpaceHierarchy, { showRoom } from "./SpaceHierarchy";
 import { type RoomPermalinkCreator } from "../../utils/permalinks/Permalinks";
+import { Icon as HashVideoIcon } from "../../../res/img/element-icons/roomlist/hash-video.svg";
+import SpacePillButton from "./SpacePillButton.tsx";
 
 interface IProps {
     space: Room;
@@ -117,7 +125,7 @@ const SpaceLandingAddButton: React.FC<{ space: Room }> = ({ space }) => {
                         <>
                             <IconizedContextMenuOption
                                 label={_t("action|new_room")}
-                                iconClassName="mx_LegacyRoomList_iconNewRoom"
+                                icon={<PlusIcon />}
                                 onClick={async (e): Promise<void> => {
                                     e.preventDefault();
                                     e.stopPropagation();
@@ -132,7 +140,7 @@ const SpaceLandingAddButton: React.FC<{ space: Room }> = ({ space }) => {
                             {videoRoomsEnabled && (
                                 <IconizedContextMenuOption
                                     label={_t("action|new_video_room")}
-                                    iconClassName="mx_LegacyRoomList_iconNewVideoRoom"
+                                    icon={<HashVideoIcon />}
                                     onClick={async (e): Promise<void> => {
                                         e.preventDefault();
                                         e.stopPropagation();
@@ -157,7 +165,7 @@ const SpaceLandingAddButton: React.FC<{ space: Room }> = ({ space }) => {
                     )}
                     <IconizedContextMenuOption
                         label={_t("action|add_existing_room")}
-                        iconClassName="mx_LegacyRoomList_iconAddExistingRoom"
+                        icon={<RoomIcon />}
                         onClick={(e) => {
                             e.preventDefault();
                             e.stopPropagation();
@@ -168,7 +176,7 @@ const SpaceLandingAddButton: React.FC<{ space: Room }> = ({ space }) => {
                     {canCreateSpace && (
                         <IconizedContextMenuOption
                             label={_t("room_list|add_space_label")}
-                            iconClassName="mx_LegacyRoomList_iconPlus"
+                            icon={<PlusIcon />}
                             onClick={(e) => {
                                 e.preventDefault();
                                 e.stopPropagation();
@@ -453,24 +461,22 @@ const SpaceSetupPrivateScope: React.FC<{
                 })}
             </div>
 
-            <AccessibleButton
-                className="mx_SpaceRoomView_privateScope_justMeButton"
+            <SpacePillButton
+                icon={<UserProfileSolidIcon />}
+                title={_t("create_space|personal_space")}
+                description={_t("create_space|personal_space_description")}
                 onClick={() => {
                     onFinished(false);
                 }}
-            >
-                {_t("create_space|personal_space")}
-                <div>{_t("create_space|personal_space_description")}</div>
-            </AccessibleButton>
-            <AccessibleButton
-                className="mx_SpaceRoomView_privateScope_meAndMyTeammatesButton"
+            />
+            <SpacePillButton
+                icon={<GroupIcon />}
+                title={_t("create_space|private_space")}
+                description={_t("create_space|private_space_description")}
                 onClick={() => {
                     onFinished(true);
                 }}
-            >
-                {_t("create_space|private_space")}
-                <div>{_t("create_space|private_space_description")}</div>
-            </AccessibleButton>
+            />
         </div>
     );
 };
