@@ -8,6 +8,14 @@ Please see LICENSE files in the repository root for full details.
 
 import React, { type JSX, createRef, type ReactNode } from "react";
 import { type Room } from "matrix-js-sdk/src/matrix";
+import {
+    ChatSolidIcon,
+    HomeSolidIcon,
+    LockSolidIcon,
+    QrCodeIcon,
+    SettingsSolidIcon,
+    LeaveIcon,
+} from "@vector-im/compound-design-tokens/assets/web/icons";
 
 import { MatrixClientPeg } from "../../MatrixClientPeg";
 import defaultDispatcher from "../../dispatcher/dispatcher";
@@ -42,7 +50,8 @@ import PosthogTrackers from "../../PosthogTrackers";
 import { type ViewHomePagePayload } from "../../dispatcher/payloads/ViewHomePagePayload";
 import { SDKContext } from "../../contexts/SDKContext";
 import { shouldShowFeedback } from "../../utils/Feedback";
-import DarkLightModeSvg from "../../../res/img/element-icons/roomlist/dark-light-mode.svg";
+import { Icon as DarkLightModeSvg } from "../../../res/img/element-icons/roomlist/dark-light-mode.svg";
+import { Icon as NotificationsIcon } from "../../../res/img/element-icons/notifications.svg";
 
 interface IProps {
     isPanelCollapsed: boolean;
@@ -297,7 +306,7 @@ export default class UserMenu extends React.Component<IProps, IState> {
         if (this.hasHomePage) {
             homeButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_UserMenu_iconHome"
+                    icon={<HomeSolidIcon />}
                     label={_t("common|home")}
                     onClick={this.onHomeClick}
                 />
@@ -308,7 +317,7 @@ export default class UserMenu extends React.Component<IProps, IState> {
         if (shouldShowFeedback()) {
             feedbackButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_UserMenu_iconMessage"
+                    icon={<ChatSolidIcon />}
                     label={_t("common|feedback")}
                     onClick={this.onProvideFeedback}
                 />
@@ -317,7 +326,7 @@ export default class UserMenu extends React.Component<IProps, IState> {
 
         const linkNewDeviceButton = (
             <IconizedContextMenuOption
-                iconClassName="mx_UserMenu_iconQr"
+                icon={<QrCodeIcon />}
                 label={_t("user_menu|link_new_device")}
                 onClick={(e) => this.onSettingsOpen(e, UserTab.SessionManager, { showMsc4108QrCode: true })}
             />
@@ -328,24 +337,24 @@ export default class UserMenu extends React.Component<IProps, IState> {
                 {homeButton}
                 {linkNewDeviceButton}
                 <IconizedContextMenuOption
-                    iconClassName="mx_UserMenu_iconBell"
+                    icon={<NotificationsIcon />}
                     label={_t("notifications|enable_prompt_toast_title")}
                     onClick={(e) => this.onSettingsOpen(e, UserTab.Notifications)}
                 />
                 <IconizedContextMenuOption
-                    iconClassName="mx_UserMenu_iconLock"
+                    icon={<LockSolidIcon />}
                     label={_t("room_settings|security|title")}
                     onClick={(e) => this.onSettingsOpen(e, UserTab.Security)}
                 />
                 <IconizedContextMenuOption
-                    iconClassName="mx_UserMenu_iconSettings"
+                    icon={<SettingsSolidIcon />}
                     label={_t("user_menu|settings")}
                     onClick={(e) => this.onSettingsOpen(e)}
                 />
                 {feedbackButton}
                 <IconizedContextMenuOption
                     className="mx_IconizedContextMenu_option_red"
-                    iconClassName="mx_UserMenu_iconSignOut"
+                    icon={<LeaveIcon />}
                     label={_t("action|sign_out")}
                     onClick={this.onSignOutClick}
                 />
@@ -357,7 +366,7 @@ export default class UserMenu extends React.Component<IProps, IState> {
                 <IconizedContextMenuOptionList>
                     {homeButton}
                     <IconizedContextMenuOption
-                        iconClassName="mx_UserMenu_iconSettings"
+                        icon={<SettingsSolidIcon />}
                         label={_t("common|settings")}
                         onClick={(e) => this.onSettingsOpen(e)}
                     />
@@ -398,7 +407,7 @@ export default class UserMenu extends React.Component<IProps, IState> {
                                 : _t("user_menu|switch_theme_dark")
                         }
                     >
-                        <img src={DarkLightModeSvg} role="presentation" alt="" width={16} />
+                        <DarkLightModeSvg width="16px" height="16px" />
                     </RovingAccessibleButton>
                 </div>
                 {topSection}
