@@ -20,6 +20,27 @@ import {
     Thread,
     M_POLL_START,
 } from "matrix-js-sdk/src/matrix";
+import {
+    CheckIcon,
+    ChevronUpIcon,
+    EditIcon,
+    ErrorSolidIcon,
+    InlineCodeIcon,
+    LinkIcon,
+    PinIcon,
+    QuoteIcon,
+    ReactionAddIcon,
+    ReplyIcon,
+    RestartIcon,
+    ThreadsIcon,
+    UnpinIcon,
+    DeleteIcon,
+    ForwardIcon,
+    PopOutIcon,
+    VisibilityOnIcon,
+    ShareIcon,
+    CopyIcon,
+} from "@vector-im/compound-design-tokens/assets/web/icons";
 
 import { MatrixClientPeg } from "../../../MatrixClientPeg";
 import dis from "../../../dispatcher/dispatcher";
@@ -53,6 +74,8 @@ import { type ShowThreadPayload } from "../../../dispatcher/payloads/ShowThreadP
 import { CardContext } from "../right_panel/context";
 import PinningUtils from "../../../utils/PinningUtils";
 import PosthogTrackers from "../../../PosthogTrackers.ts";
+import { Icon as ViewInRoomIcon } from "../../../../res/img/element-icons/view-in-room.svg";
+import { Icon as ChildRelationshipIcon } from "../../../../res/img/element-icons/child-relationship.svg";
 
 interface IReplyInThreadButton {
     mxEvent: MatrixEvent;
@@ -86,13 +109,7 @@ const ReplyInThreadButton: React.FC<IReplyInThreadButton> = ({ mxEvent, closeMen
         closeMenu();
     };
 
-    return (
-        <IconizedContextMenuOption
-            iconClassName="mx_MessageContextMenu_iconReplyInThread"
-            label={_t("action|reply_in_thread")}
-            onClick={onClick}
-        />
-    );
+    return <IconizedContextMenuOption icon={<ThreadsIcon />} label={_t("action|reply_in_thread")} onClick={onClick} />;
 };
 
 interface IProps extends MenuProps {
@@ -255,7 +272,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         dis.dispatch<OpenForwardDialogPayload>({
             action: Action.OpenForwardDialog,
             event: forwardableEvent,
-            permalinkCreator: this.props.permalinkCreator,
+            permalinkCreator: this.props.permalinkCreator ?? null,
         });
         this.closeMenu();
     };
@@ -413,7 +430,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (!mxEvent.isRedacted() && unsentReactionsCount !== 0) {
             resendReactionsButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconResend"
+                    icon={<RestartIcon />}
                     label={_t("timeline|context_menu|resent_unsent_reactions", { unsentCount: unsentReactionsCount })}
                     onClick={this.onResendReactionsClick}
                 />
@@ -424,7 +441,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (isSent && this.state.canRedact) {
             redactButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconRedact"
+                    icon={<DeleteIcon />}
                     label={_t("action|remove")}
                     onClick={this.onRedactClick}
                 />
@@ -437,7 +454,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
             const mapSiteLink = createMapSiteLinkFromEvent(shareableLocationEvent);
             openInMapSiteButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconOpenInMapSite"
+                    icon={<PopOutIcon />}
                     onClick={null}
                     label={_t("timeline|context_menu|open_in_osm")}
                     element="a"
@@ -455,7 +472,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (contentActionable && forwardableEvent) {
             forwardButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconForward"
+                    icon={<ForwardIcon />}
                     label={_t("action|forward")}
                     onClick={this.onForwardClick(forwardableEvent)}
                 />
@@ -465,7 +482,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         // This is specifically not behind the developerMode flag to give people insight into the Matrix
         const viewSourceButton = (
             <IconizedContextMenuOption
-                iconClassName="mx_MessageContextMenu_iconSource"
+                icon={<InlineCodeIcon />}
                 label={_t("timeline|context_menu|view_source")}
                 onClick={this.onViewSourceClick}
             />
@@ -475,7 +492,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (eventTileOps?.isWidgetHidden()) {
             unhidePreviewButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconUnhidePreview"
+                    icon={<VisibilityOnIcon />}
                     label={_t("timeline|context_menu|show_url_preview")}
                     onClick={this.onUnhidePreviewClick}
                 />
@@ -486,7 +503,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (permalink) {
             permalinkButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconPermalink"
+                    icon={<ShareIcon />}
                     onClick={this.onShareClick}
                     label={_t("action|share")}
                     element="a"
@@ -506,7 +523,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (this.canEndPoll(mxEvent)) {
             endPollButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconEndPoll"
+                    icon={<CheckIcon />}
                     label={_t("poll|end_title")}
                     onClick={this.onEndPollClick}
                 />
@@ -521,7 +538,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         ) {
             externalURLButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconLink"
+                    icon={<LinkIcon />}
                     onClick={this.closeMenu}
                     label={_t("timeline|context_menu|external_url")}
                     element="a"
@@ -541,7 +558,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (collapseReplyChain) {
             collapseReplyChainButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconCollapse"
+                    icon={<ChevronUpIcon />}
                     label={_t("timeline|context_menu|collapse_reply_thread")}
                     onClick={this.onCollapseReplyChainClick}
                 />
@@ -553,7 +570,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (relatedEventId && SettingsStore.getValue("developerMode")) {
             jumpToRelatedEventButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_jumpToEvent"
+                    icon={<ChildRelationshipIcon />}
                     label={_t("timeline|context_menu|view_related_event")}
                     onClick={() => this.onJumpToRelatedEventClick(relatedEventId)}
                 />
@@ -564,7 +581,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (mxEvent.getSender() !== me) {
             reportEventButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconReport"
+                    icon={<ErrorSolidIcon />}
                     label={_t("timeline|context_menu|report")}
                     onClick={this.onReportEventClick}
                 />
@@ -575,7 +592,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (link) {
             copyLinkButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconCopy"
+                    icon={<CopyIcon />}
                     onClick={this.onCopyLinkClick}
                     label={_t("action|copy_link")}
                     element="a"
@@ -597,7 +614,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (rightClick && selectedText) {
             copyButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconCopy"
+                    icon={<CopyIcon />}
                     label={_t("action|copy")}
                     triggerOnMouseDown={true} // We use onMouseDown so that the selection isn't cleared when we click
                     onClick={this.onCopyClick}
@@ -609,7 +626,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (rightClick && selectedText && selectedText.trim().length > 0 && this.isSelectionWithinSingleTextBody()) {
             quoteButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconQuote"
+                    icon={<QuoteIcon />}
                     label={_t("action|quote")}
                     triggerOnMouseDown={true}
                     onClick={this.onQuoteClick}
@@ -620,11 +637,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         let editButton: JSX.Element | undefined;
         if (rightClick && canEditContent(cli, mxEvent)) {
             editButton = (
-                <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconEdit"
-                    label={_t("action|edit")}
-                    onClick={this.onEditClick}
-                />
+                <IconizedContextMenuOption icon={<EditIcon />} label={_t("action|edit")} onClick={this.onEditClick} />
             );
         }
 
@@ -632,7 +645,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (rightClick && contentActionable && canSendMessages) {
             replyButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconReply"
+                    icon={<ReplyIcon />}
                     label={_t("action|reply")}
                     onClick={this.onReplyClick}
                 />
@@ -654,7 +667,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (rightClick && contentActionable && canReact) {
             reactButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconReact"
+                    icon={<ReactionAddIcon />}
                     label={_t("action|react")}
                     onClick={this.onReactClick}
                     inputRef={this.reactButtonRef}
@@ -667,7 +680,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
             const isPinned = PinningUtils.isPinned(MatrixClientPeg.safeGet(), this.props.mxEvent);
             pinButton = (
                 <IconizedContextMenuOption
-                    iconClassName={isPinned ? "mx_MessageContextMenu_iconUnpin" : "mx_MessageContextMenu_iconPin"}
+                    icon={isPinned ? <UnpinIcon /> : <PinIcon />}
                     label={isPinned ? _t("action|unpin") : _t("action|pin")}
                     onClick={() => this.onPinClick(isPinned)}
                 />
@@ -678,7 +691,7 @@ export default class MessageContextMenu extends React.Component<IProps, IState>
         if (isThreadRootEvent) {
             viewInRoomButton = (
                 <IconizedContextMenuOption
-                    iconClassName="mx_MessageContextMenu_iconViewInRoom"
+                    icon={<ViewInRoomIcon />}
                     label={_t("timeline|mab|view_in_room")}
                     onClick={this.viewInRoom}
                 />
