@@ -7,7 +7,6 @@ Please see LICENSE files in the repository root for full details.
 */
 
 import React, { type RefObject, useContext } from "react";
-import classNames from "classnames";
 
 import AccessibleButton, { type ButtonProps } from "../elements/AccessibleButton";
 import { OverflowMenuContext } from "./MessageComposerButtons";
@@ -16,24 +15,16 @@ import { IconizedContextMenuOption } from "../context_menus/IconizedContextMenu"
 interface Props extends Omit<ButtonProps<"div">, "element"> {
     inputRef?: RefObject<HTMLElement | null>;
     title: string;
-    iconClassName: string;
 }
 
-export const CollapsibleButton: React.FC<Props> = ({
-    title,
-    children,
-    className,
-    iconClassName,
-    inputRef,
-    ...props
-}) => {
+export const CollapsibleButton: React.FC<Props> = ({ title, children, className, inputRef, ...props }) => {
     const inOverflowMenu = !!useContext(OverflowMenuContext);
     if (inOverflowMenu) {
-        return <IconizedContextMenuOption {...props} iconClassName={iconClassName} label={title} inputRef={inputRef} />;
+        return <IconizedContextMenuOption {...props} icon={children} label={title} inputRef={inputRef} />;
     }
 
     return (
-        <AccessibleButton {...props} title={title} className={classNames(className, iconClassName)} ref={inputRef}>
+        <AccessibleButton {...props} title={title} className={className} ref={inputRef}>
             {children}
         </AccessibleButton>
     );
