@@ -7,6 +7,7 @@ Please see LICENSE files in the repository root for full details.
 
 import React from "react";
 import classNames from "classnames";
+import { ChevronDownIcon } from "@vector-im/compound-design-tokens/assets/web/icons";
 
 import { _t } from "../../../languageHandler";
 import AccessibleButton, { type ButtonEvent } from "../elements/AccessibleButton";
@@ -32,7 +33,9 @@ const JumpToBottomButton: React.FC<IProps> = (props) => {
                 className="mx_JumpToBottomButton_scrollDown"
                 title={_t("room|jump_to_bottom_button")}
                 onClick={props.onScrollToBottomClick}
-            />
+            >
+                <ChevronDownIcon />
+            </AccessibleButton>
             {badge}
         </div>
     );
