@@ -5,7 +5,7 @@
  * Please see LICENSE files in the repository root for full details.
  */
 
-import React, { type JSX, memo, useCallback, useEffect, useRef, useState } from "react";
+import React, { type JSX, memo, useEffect, useRef } from "react";
 import { type Room } from "matrix-js-sdk/src/matrix";
 import classNames from "classnames";
 import { Flex } from "@element-hq/web-shared-components";
@@ -57,18 +57,6 @@ export const RoomListItemView = memo(function RoomListItemView({
 }: RoomListItemViewProps): JSX.Element {
     const ref = useRef<HTMLButtonElement>(null);
     const vm = useRoomListItemViewModel(room);
-    const [isHover, setHover] = useState(false);
-    const [isMenuOpen, setIsMenuOpen] = useState(false);
-    // The compound menu in RoomListItemMenuView needs to be rendered when the hover menu is shown
-    // Using display: none; and then display:flex when hovered in CSS causes the menu to be misaligned
-    const showHoverDecoration = isMenuOpen || isFocused || isHover;
-    const showHoverMenu = showHoverDecoration && vm.showHoverMenu;
-
-    const closeMenu = useCallback(() => {
-        // To avoid icon blinking when closing the menu, we delay the state update
-        // Also, let the focus move to the menu trigger before closing the menu
-        setTimeout(() => setIsMenuOpen(false), 10);
-    }, []);
 
     useEffect(() => {
         if (isFocused) {
@@ -81,8 +69,7 @@ export const RoomListItemView = memo(function RoomListItemView({
             as="button"
             ref={ref}
             className={classNames("mx_RoomListItemView", {
-                mx_RoomListItemView_hover: showHoverDecoration,
-                mx_RoomListItemView_menu_open: showHoverMenu,
+                mx_RoomListItemView_has_menu: vm.showHoverMenu,
                 mx_RoomListItemView_selected: isSelected,
                 mx_RoomListItemView_bold: vm.isBold,
             })}
@@ -96,9 +83,6 @@ export const RoomListItemView = memo(function RoomListItemView({
             aria-label={vm.a11yLabel}
             onClick={() => vm.openRoom()}
             onFocus={(e: React.FocusEvent<HTMLButtonElement>) => onFocus(room, e)}
-            onMouseOver={() => setHover(true)}
-            onMouseOut={() => setHover(false)}
-            onBlur={() => setHover(false)}
             tabIndex={isFocused ? 0 : -1}
             {...props}
         >
@@ -120,44 +104,21 @@ export const RoomListItemView = memo(function RoomListItemView({
                         </div>
                     )}
                 </div>
-                {showHoverMenu ? (
-                    <RoomListItemMenuView
-                        room={room}
-                        setMenuOpen={(isOpen) => (isOpen ? setIsMenuOpen(true) : closeMenu())}
+                {vm.showHoverMenu && <RoomListItemMenuView className="mx_RoomListItemView_menu" room={room} />}
+
+                {/* aria-hidden because we summarise the unread count/notification status in a11yLabel variable */}
+                {vm.showNotificationDecoration && (
+                    <NotificationDecoration
+                        className="mx_RoomListItemView_notificationDecoration"
+                        notificationState={vm.notificationState}
+                        aria-hidden={true}
+                        callType={vm.callType}
                     />
-                ) : (
-                    <>
-                        {/* aria-hidden because we summarise the unread count/notification status in a11yLabel variable */}
-                        {vm.showNotificationDecoration && (
-                            <NotificationDecoration
-                                notificationState={vm.notificationState}
-                                aria-hidden={true}
-                                callType={vm.callType}
-                            />
-                        )}
-                    </>
                 )}
             </Flex>
         </Flex>
     );
 
-    // Rendering multiple context menus can causes crashes in radix upstream,
-    // See https://github.com/radix-ui/primitives/issues/2717.
     if (!vm.showContextMenu) return content;
-
-    return (
-        <RoomListItemContextMenuView
-            room={room}
-            setMenuOpen={(isOpen) => {
-                if (isOpen) {
-                    // To avoid icon blinking when the context menu is re-opened
-                    setTimeout(() => setIsMenuOpen(true), 0);
-                } else {
-                    closeMenu();
-                }
-            }}
-        >
-            {content}
-        </RoomListItemContextMenuView>
-    );
+    return <RoomListItemContextMenuView room={room}>{content}</RoomListItemContextMenuView>;
 });
