@@ -7,6 +7,7 @@ Please see LICENSE files in the repository root for full details.
 */
 
 import React from "react";
+import { Form } from "@vector-im/compound-web";
 
 import { Features } from "../../../../../settings/Settings";
 import SettingsStore from "../../../../../settings/SettingsStore";
@@ -21,13 +22,20 @@ export default class NotificationUserSettingsTab extends React.Component {
 
         return (
             <SettingsTab>
-                {newNotificationSettingsEnabled ? (
-                    <NotificationSettings2 />
-                ) : (
-                    <SettingsSection>
-                        <Notifications />
-                    </SettingsSection>
-                )}
+                <Form.Root
+                    onSubmit={(evt) => {
+                        evt.preventDefault();
+                        evt.stopPropagation();
+                    }}
+                >
+                    {newNotificationSettingsEnabled ? (
+                        <NotificationSettings2 />
+                    ) : (
+                        <SettingsSection>
+                            <Notifications />
+                        </SettingsSection>
+                    )}
+                </Form.Root>
             </SettingsTab>
         );
     }
