@@ -22,6 +22,15 @@ import React, {
 import { DragDropContext, Draggable, Droppable, type DroppableProvidedProps } from "react-beautiful-dnd";
 import classNames from "classnames";
 import { type Room } from "matrix-js-sdk/src/matrix";
+import {
+    FavouriteSolidIcon,
+    HomeSolidIcon,
+    RoomIcon,
+    VideoCallSolidIcon,
+    UserProfileSolidIcon,
+    PlusIcon,
+    ChevronRightIcon,
+} from "@vector-im/compound-design-tokens/assets/web/icons";
 
 import { _t } from "../../../languageHandler";
 import { useContextMenu } from "../../structures/ContextMenu";
@@ -70,7 +79,6 @@ import { Landmark, LandmarkNavigation } from "../../../accessibility/LandmarkNav
 import { KeyboardShortcut } from "../settings/KeyboardShortcut";
 import { ModuleApi } from "../../../modules/Api.ts";
 import { useModuleSpacePanelItems } from "../../../modules/ExtrasApi.ts";
-import { ReleaseAnnouncement } from "../../structures/ReleaseAnnouncement";
 
 const useSpaces = (): [Room[], MetaSpace[], Room[], SpaceKey] => {
     const invites = useEventEmitterState<Room[]>(SpaceStore.instance, UPDATE_INVITED_SPACES, () => {
@@ -99,7 +107,6 @@ export const HomeButtonContextMenu: React.FC<ComponentProps<typeof SpaceContextM
             {!hideHeader && <div className="mx_SpacePanel_contextMenu_header">{_t("common|home")}</div>}
             <IconizedContextMenuOptionList first>
                 <IconizedContextMenuCheckbox
-                    iconClassName="mx_SpacePanel_noIcon"
                     label={_t("settings|sidebar|metaspaces_home_all_rooms")}
                     active={allRoomsInHome}
                     onClick={() => {
@@ -115,6 +122,7 @@ export const HomeButtonContextMenu: React.FC<ComponentProps<typeof SpaceContextM
 interface IMetaSpaceButtonProps extends ComponentProps<typeof SpaceButton> {
     selected: boolean;
     isPanelCollapsed: boolean;
+    icon: JSX.Element;
 }
 
 type MetaSpaceButtonProps = Pick<IMetaSpaceButtonProps, "selected" | "isPanelCollapsed">;
@@ -153,7 +161,6 @@ const HomeButton: React.FC<MetaSpaceButtonProps> = ({ selected, isPanelCollapsed
     return (
         <MetaSpaceButton
             spaceKey={MetaSpace.Home}
-            className="mx_SpaceButton_home"
             selected={selected}
             isPanelCollapsed={isPanelCollapsed}
             label={getMetaSpaceName(MetaSpace.Home, allRoomsInHome)}
@@ -161,6 +168,7 @@ const HomeButton: React.FC<MetaSpaceButtonProps> = ({ selected, isPanelCollapsed
             ContextMenuComponent={HomeButtonContextMenu}
             contextMenuTooltip={_t("common|options")}
             size="32px"
+            icon={<HomeSolidIcon />}
         />
     );
 };
@@ -169,12 +177,12 @@ const FavouritesButton: React.FC<MetaSpaceButtonProps> = ({ selected, isPanelCol
     return (
         <MetaSpaceButton
             spaceKey={MetaSpace.Favourites}
-            className="mx_SpaceButton_favourites"
             selected={selected}
             isPanelCollapsed={isPanelCollapsed}
             label={getMetaSpaceName(MetaSpace.Favourites)}
             notificationState={SpaceStore.instance.getNotificationState(MetaSpace.Favourites)}
             size="32px"
+            icon={<FavouriteSolidIcon />}
         />
     );
 };
@@ -183,12 +191,12 @@ const PeopleButton: React.FC<MetaSpaceButtonProps> = ({ selected, isPanelCollaps
     return (
         <MetaSpaceButton
             spaceKey={MetaSpace.People}
-            className="mx_SpaceButton_people"
             selected={selected}
             isPanelCollapsed={isPanelCollapsed}
             label={getMetaSpaceName(MetaSpace.People)}
             notificationState={SpaceStore.instance.getNotificationState(MetaSpace.People)}
             size="32px"
+            icon={<UserProfileSolidIcon />}
         />
     );
 };
@@ -197,12 +205,12 @@ const OrphansButton: React.FC<MetaSpaceButtonProps> = ({ selected, isPanelCollap
     return (
         <MetaSpaceButton
             spaceKey={MetaSpace.Orphans}
-            className="mx_SpaceButton_orphans"
             selected={selected}
             isPanelCollapsed={isPanelCollapsed}
             label={getMetaSpaceName(MetaSpace.Orphans)}
             notificationState={SpaceStore.instance.getNotificationState(MetaSpace.Orphans)}
             size="32px"
+            icon={<RoomIcon />}
         />
     );
 };
@@ -211,12 +219,12 @@ const VideoRoomsButton: React.FC<MetaSpaceButtonProps> = ({ selected, isPanelCol
     return (
         <MetaSpaceButton
             spaceKey={MetaSpace.VideoRooms}
-            className="mx_SpaceButton_videoRooms"
             selected={selected}
             isPanelCollapsed={isPanelCollapsed}
             label={getMetaSpaceName(MetaSpace.VideoRooms)}
             notificationState={SpaceStore.instance.getNotificationState(MetaSpace.VideoRooms)}
             size="32px"
+            icon={<VideoCallSolidIcon />}
         />
     );
 };
@@ -263,6 +271,7 @@ const CreateSpaceButton: React.FC<Pick<IInnerSpacePanelProps, "isPanelCollapsed"
                 isNarrow={isPanelCollapsed}
                 innerRef={handle}
                 size="32px"
+                icon={<PlusIcon />}
             />
 
             {contextMenu}
@@ -405,72 +414,65 @@ const SpacePanel: React.FC = () => {
                         onDragEndHandler();
                     }}
                 >
-                    <ReleaseAnnouncement
-                        feature="newNotificationSounds"
-                        header={_t("settings|notifications|sounds_release_announcement|title")}
-                        description={_t("settings|notifications|sounds_release_announcement|description")}
-                        closeLabel={_t("action|ok")}
-                        displayArrow={false}
-                        placement="right-start"
+                    <nav
+                        className={classNames("mx_SpacePanel", {
+                            collapsed: isPanelCollapsed,
+                            newUi: newRoomListEnabled,
+                        })}
+                        onKeyDown={(ev) => {
+                            const navAction = getKeyBindingsManager().getNavigationAction(ev);
+                            if (
+                                navAction === KeyBindingAction.NextLandmark ||
+                                navAction === KeyBindingAction.PreviousLandmark
+                            ) {
+                                LandmarkNavigation.findAndFocusNextLandmark(
+                                    Landmark.ACTIVE_SPACE_BUTTON,
+                                    navAction === KeyBindingAction.PreviousLandmark,
+                                );
+                                ev.stopPropagation();
+                                ev.preventDefault();
+                                return;
+                            }
+                            onKeyDownHandler(ev);
+                        }}
+                        ref={ref}
+                        aria-label={_t("common|spaces")}
                     >
-                        <nav
-                            className={classNames("mx_SpacePanel", {
-                                collapsed: isPanelCollapsed,
-                                newUi: newRoomListEnabled,
-                            })}
-                            onKeyDown={(ev) => {
-                                const navAction = getKeyBindingsManager().getNavigationAction(ev);
-                                if (
-                                    navAction === KeyBindingAction.NextLandmark ||
-                                    navAction === KeyBindingAction.PreviousLandmark
-                                ) {
-                                    LandmarkNavigation.findAndFocusNextLandmark(
-                                        Landmark.ACTIVE_SPACE_BUTTON,
-                                        navAction === KeyBindingAction.PreviousLandmark,
-                                    );
-                                    ev.stopPropagation();
-                                    ev.preventDefault();
-                                    return;
+                        <UserMenu isPanelCollapsed={isPanelCollapsed}>
+                            <AccessibleButton
+                                className={classNames("mx_SpacePanel_toggleCollapse", {
+                                    expanded: !isPanelCollapsed,
+                                })}
+                                onClick={() => setPanelCollapsed(!isPanelCollapsed)}
+                                title={isPanelCollapsed ? _t("action|expand") : _t("action|collapse")}
+                                caption={
+                                    <KeyboardShortcut
+                                        value={{ ctrlOrCmdKey: true, shiftKey: true, key: "d" }}
+                                        className="mx_SpacePanel_Tooltip_KeyboardShortcut"
+                                    />
                                 }
-                                onKeyDownHandler(ev);
-                            }}
-                            ref={ref}
-                            aria-label={_t("common|spaces")}
-                        >
-                            <UserMenu isPanelCollapsed={isPanelCollapsed}>
-                                <AccessibleButton
-                                    className={classNames("mx_SpacePanel_toggleCollapse", {
-                                        expanded: !isPanelCollapsed,
-                                    })}
-                                    onClick={() => setPanelCollapsed(!isPanelCollapsed)}
-                                    title={isPanelCollapsed ? _t("action|expand") : _t("action|collapse")}
-                                    caption={
-                                        <KeyboardShortcut
-                                            value={{ ctrlOrCmdKey: true, shiftKey: true, key: "d" }}
-                                            className="mx_SpacePanel_Tooltip_KeyboardShortcut"
-                                        />
-                                    }
-                                />
-                            </UserMenu>
-                            <Droppable droppableId="top-level-spaces">
-                                {(provided, snapshot) => (
-                                    <InnerSpacePanel
-                                        {...provided.droppableProps}
-                                        isPanelCollapsed={isPanelCollapsed}
-                                        setPanelCollapsed={setPanelCollapsed}
-                                        isDraggingOver={snapshot.isDraggingOver}
-                                        innerRef={provided.innerRef}
-                                    >
-                                        {provided.placeholder}
-                                    </InnerSpacePanel>
-                                )}
-                            </Droppable>
+                            >
+                                <ChevronRightIcon />
+                            </AccessibleButton>
+                        </UserMenu>
+                        <Droppable droppableId="top-level-spaces">
+                            {(provided, snapshot) => (
+                                <InnerSpacePanel
+                                    {...provided.droppableProps}
+                                    isPanelCollapsed={isPanelCollapsed}
+                                    setPanelCollapsed={setPanelCollapsed}
+                                    isDraggingOver={snapshot.isDraggingOver}
+                                    innerRef={provided.innerRef}
+                                >
+                                    {provided.placeholder}
+                                </InnerSpacePanel>
+                            )}
+                        </Droppable>
 
-                            <ThreadsActivityCentre displayButtonLabel={!isPanelCollapsed} />
+                        <ThreadsActivityCentre displayButtonLabel={!isPanelCollapsed} />
 
-                            <QuickSettingsButton isPanelCollapsed={isPanelCollapsed} />
-                        </nav>
-                    </ReleaseAnnouncement>
+                        <QuickSettingsButton isPanelCollapsed={isPanelCollapsed} />
+                    </nav>
                 </DragDropContext>
             )}
         </RovingTabIndexProvider>
