@@ -6,7 +6,6 @@ SPDX-License-Identifier: AGPL-3.0-only OR GPL-3.0-only OR LicenseRef-Element-Com
 Please see LICENSE files in the repository root for full details.
 */
 
-import { type Optional } from "matrix-events-sdk";
 import { type MatrixCall } from "matrix-js-sdk/src/webrtc/call";
 
 import { type ActionPayload } from "../payloads";
@@ -17,7 +16,7 @@ export interface OpenInviteDialogPayload extends ActionPayload {
     action: Action.OpenInviteDialog;
 
     kind: InviteKind;
-    onFinishedCallback: Optional<(results: boolean[]) => void>;
+    onFinishedCallback?: (results: boolean[]) => void;
 
     call?: MatrixCall;
     roomId?: string;
