@@ -10,11 +10,9 @@ import React, { type JSX, useCallback, useEffect, useRef, useState } from "react
 import { type Room, type MatrixEvent, type RoomMember, RoomEvent, EventType } from "matrix-js-sdk/src/matrix";
 import { Button, ToggleInput, Tooltip, TooltipProvider } from "@vector-im/compound-web";
 import VideoCallIcon from "@vector-im/compound-design-tokens/assets/web/icons/video-call-solid";
-import CheckIcon from "@vector-im/compound-design-tokens/assets/web/icons/check";
-import CrossIcon from "@vector-im/compound-design-tokens/assets/web/icons/close";
 import { logger } from "matrix-js-sdk/src/logger";
 import { type IRTCNotificationContent } from "matrix-js-sdk/src/matrixrtc";
-import { VoiceCallIcon } from "@vector-im/compound-design-tokens/assets/web/icons";
+import { CheckIcon, VoiceCallIcon, CloseIcon } from "@vector-im/compound-design-tokens/assets/web/icons";
 import { AvatarWithDetails } from "@element-hq/web-shared-components";
 
 import { _t } from "../languageHandler";
@@ -25,7 +23,7 @@ import { type ViewRoomPayload } from "../dispatcher/payloads/ViewRoomPayload";
 import { Action } from "../dispatcher/actions";
 import ToastStore from "../stores/ToastStore";
 import { LiveContentSummary, LiveContentType } from "../components/views/rooms/LiveContentSummary";
-import { useCall, useJoinCallButtonDisabledTooltip, useParticipantCount } from "../hooks/useCall";
+import { useCall, useParticipantCount } from "../hooks/useCall";
 import AccessibleButton, { type ButtonEvent } from "../components/views/elements/AccessibleButton";
 import { useDispatcher } from "../hooks/useDispatcher";
 import { type ActionPayload } from "../dispatcher/payloads";
@@ -72,22 +70,13 @@ interface JoinCallButtonWithCallProps {
     isRinging: boolean;
 }
 
-function JoinCallButtonWithCall({
-    onClick,
-    call,
-    disabledTooltip,
-    isRinging,
-}: JoinCallButtonWithCallProps): JSX.Element {
-    let disTooltip = disabledTooltip;
-    const disabledBecauseFullTooltip = useJoinCallButtonDisabledTooltip(call);
-    disTooltip = disabledTooltip ?? disabledBecauseFullTooltip ?? undefined;
-
+function JoinCallButtonWithCall({ onClick, disabledTooltip, isRinging }: JoinCallButtonWithCallProps): JSX.Element {
     return (
-        <Tooltip description={disTooltip ?? _t("voip|video_call")}>
+        <Tooltip description={disabledTooltip ?? _t("voip|video_call")}>
             <Button
                 className="mx_IncomingCallToast_actionButton"
                 onClick={onClick}
-                disabled={disTooltip != undefined}
+                disabled={disabledTooltip != undefined}
                 kind="primary"
                 Icon={CheckIcon}
                 size="sm"
@@ -127,7 +116,7 @@ function DeclineCallButtonWithNotificationEvent({
                 kind="primary"
                 destructive
                 disabled={declining}
-                Icon={CrossIcon}
+                Icon={CloseIcon}
                 size="sm"
             >
                 {_t("action|decline")}
@@ -332,7 +321,9 @@ export function IncomingCallToast({ notificationEvent }: Props): JSX.Element {
                     className="mx_IncomingCallToast_closeButton"
                     onClick={onCloseClick}
                     title={_t("action|close")}
-                />
+                >
+                    <CloseIcon />
+                </AccessibleButton>
             </>
         </TooltipProvider>
     );
