@@ -33,6 +33,7 @@ import { UserFriendlyError } from "../languageHandler";
 import { ModuleApi } from "../modules/Api";
 import { RoomView } from "../components/structures/RoomView";
 import RoomAvatar from "../components/views/avatars/RoomAvatar";
+import { ModuleNotificationDecoration } from "../modules/components/ModuleNotificationDecoration";
 
 logger.log(`Application is running in ${process.env.NODE_ENV} mode`);
 
@@ -58,7 +59,11 @@ function onTokenLoginCompleted(): void {
 export async function loadApp(fragParams: QueryDict, matrixChatRef: React.Ref<MatrixChat>): Promise<ReactElement> {
     // XXX: This lives here because certain components import so many things that importing it in a sensible place (eg.
     // the builtins module or init.tsx) causes a circular dependency.
-    ModuleApi.instance.builtins.setComponents({ roomView: RoomView, roomAvatar: RoomAvatar });
+    ModuleApi.instance.builtins.setComponents({
+        roomView: RoomView,
+        roomAvatar: RoomAvatar,
+        notificationDecoration: ModuleNotificationDecoration,
+    });
 
     initRouting();
     const platform = PlatformPeg.get();
