@@ -9,6 +9,7 @@ Please see LICENSE files in the repository root for full details.
 import EventEmitter from "events";
 import { mocked, type MockedObject } from "jest-mock";
 import {
+    type EventTimeline,
     MatrixEvent,
     type Room,
     type User,
@@ -16,8 +17,7 @@ import {
     type IEvent,
     type RoomMember,
     type MatrixClient,
-    type EventTimeline,
-    type RoomState,
+    RoomState,
     EventType,
     type IEventRelation,
     type IUnsigned,
@@ -30,6 +30,8 @@ import {
     JoinRule,
     type OidcClientConfig,
     type GroupCall,
+    HistoryVisibility,
+    type ICreateRoomOpts,
 } from "matrix-js-sdk/src/matrix";
 import { KnownMembership } from "matrix-js-sdk/src/types";
 import { normalize } from "matrix-js-sdk/src/utils";
@@ -84,6 +86,7 @@ export function createTestClient(): MatrixClient {
     const eventEmitter = new EventEmitter();
 
     let txnId = 1;
+    let createdRoom: Room | undefined;
 
     const client = {
         getHomeserverUrl: jest.fn(),
@@ -123,6 +126,7 @@ export function createTestClient(): MatrixClient {
             getDeviceVerificationStatus: jest.fn(),
             resetKeyBackup: jest.fn(),
             isEncryptionEnabledInRoom: jest.fn().mockResolvedValue(false),
+            isStateEncryptionEnabledInRoom: jest.fn().mockResolvedValue(false),
             getVerificationRequestsToDeviceInProgress: jest.fn().mockReturnValue([]),
             setDeviceIsolationMode: jest.fn(),
             prepareToEncrypt: jest.fn(),
@@ -161,7 +165,14 @@ export function createTestClient(): MatrixClient {
         }),
 
         getPushActionsForEvent: jest.fn(),
-        getRoom: jest.fn().mockImplementation((roomId) => mkStubRoom(roomId, "My room", client)),
+        getRoom: jest.fn().mockImplementation((roomId) => {
+            // If the test called `createRoom`, return the mocked room it created.
+            if (createdRoom) {
+                return createdRoom;
+            } else {
+                return mkStubRoom(roomId, "My room", client);
+            }
+        }),
         getRooms: jest.fn().mockReturnValue([]),
         getVisibleRooms: jest.fn().mockReturnValue([]),
         loginFlows: jest.fn(),
@@ -200,6 +211,7 @@ export function createTestClient(): MatrixClient {
         setAccountData: jest.fn(),
         deleteAccountData: jest.fn(),
         setRoomAccountData: jest.fn(),
+        setRoomName: jest.fn(),
         setRoomTopic: jest.fn(),
         setRoomReadMarkers: jest.fn().mockResolvedValue({}),
         sendTyping: jest.fn().mockResolvedValue({}),
@@ -212,7 +224,23 @@ export function createTestClient(): MatrixClient {
         getRoomHierarchy: jest.fn().mockReturnValue({
             rooms: [],
         }),
-        createRoom: jest.fn().mockResolvedValue({ room_id: "!1:example.org" }),
+        createRoom: jest.fn(async (createOpts?: ICreateRoomOpts) => {
+            const initialState = createOpts?.initial_state?.map((event, i) =>
+                mkEvent({
+                    ...event,
+                    room: "!1:example.org",
+                    user: "@user:example.com",
+                    event: true,
+                }),
+            );
+            createdRoom = mkStubRoom(
+                "!1:example.org",
+                "My room",
+                client,
+                initialState && mkRoomState("!1:example.org", initialState),
+            );
+            return { room_id: "!1:example.org" };
+        }),
         setPowerLevel: jest.fn().mockResolvedValue(undefined),
         pushRules: {},
         decryptEventIfNeeded: () => Promise.resolve(),
@@ -280,6 +308,8 @@ export function createTestClient(): MatrixClient {
         _unstable_cancelScheduledDelayedEvent: jest.fn(),
         _unstable_restartScheduledDelayedEvent: jest.fn(),
         _unstable_sendScheduledDelayedEvent: jest.fn(),
+        _unstable_sendStickyEvent: jest.fn(),
+        _unstable_sendStickyDelayedEvent: jest.fn(),
 
         searchUserDirectory: jest.fn().mockResolvedValue({ limited: false, results: [] }),
         setDeviceVerified: jest.fn(),
@@ -615,10 +645,11 @@ export function mkStubRoom(
     roomId: string | null | undefined = null,
     name: string | undefined,
     client: MatrixClient | undefined,
+    state?: RoomState | undefined,
 ): Room {
     const stubTimeline = {
         getEvents: (): MatrixEvent[] => [],
-        getState: (): RoomState | undefined => undefined,
+        getState: (): RoomState | undefined => state,
     } as unknown as EventTimeline;
     return {
         canInvite: jest.fn().mockReturnValue(false),
@@ -627,6 +658,7 @@ export function mkStubRoom(
         createThreadsTimelineSets: jest.fn().mockReturnValue(new Promise(() => {})),
         currentState: {
             getStateEvents: jest.fn((_type, key) => (key === undefined ? [] : null)),
+            getHistoryVisibility: jest.fn().mockReturnValue(HistoryVisibility.Joined),
             getMember: jest.fn(),
             mayClientSendStateEvent: jest.fn().mockReturnValue(true),
             maySendStateEvent: jest.fn().mockReturnValue(true),
@@ -647,6 +679,7 @@ export function mkStubRoom(
         getCanonicalAlias: jest.fn(),
         getDMInviter: jest.fn(),
         getEventReadUpTo: jest.fn(() => null),
+        getHistoryVisibility: jest.fn().mockReturnValue(HistoryVisibility.Joined),
         getInvitedAndJoinedMemberCount: jest.fn().mockReturnValue(1),
         getJoinRule: jest.fn().mockReturnValue("invite"),
         getJoinedMemberCount: jest.fn().mockReturnValue(1),
@@ -699,6 +732,22 @@ export function mkStubRoom(
     } as unknown as Room;
 }
 
+export function mkRoomState(
+    roomId: string = "!1:example.org",
+    stateEvents: MatrixEvent[] = [],
+    members: RoomMember[] = [],
+): RoomState {
+    const roomState = new RoomState(roomId);
+
+    roomState.setStateEvents(stateEvents);
+
+    for (const member of members) {
+        roomState.members[member.userId] = member;
+    }
+
+    return roomState;
+}
+
 export function mkServerConfig(
     hsUrl: string,
     isUrl: string,
