@@ -341,9 +341,7 @@ describe("DeviceListener", () => {
                 await createAndStart();
 
                 expect(mockCrypto!.getUserDeviceInfo).toHaveBeenCalled();
-                expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith(
-                    SetupEncryptionToast.Kind.VERIFY_THIS_SESSION,
-                );
+                expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith("verify_this_session");
             });
 
             describe("when current device is verified", () => {
@@ -367,7 +365,7 @@ describe("DeviceListener", () => {
                     expect(SetupEncryptionToast.hideToast).toHaveBeenCalled();
                 });
 
-                it("shows an out-of-sync toast when one of the secrets is missing locally", async () => {
+                it("shows an out-of-sync toast when one of the cross-signing secrets is missing locally", async () => {
                     mockCrypto!.getCrossSigningStatus.mockResolvedValue({
                         publicKeysOnDevice: true,
                         privateKeysInSecretStorage: true,
@@ -380,9 +378,45 @@ describe("DeviceListener", () => {
 
                     await createAndStart();
 
-                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith(
-                        SetupEncryptionToast.Kind.KEY_STORAGE_OUT_OF_SYNC,
+                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith("key_storage_out_of_sync");
+                });
+
+                it("shows an identity reset toast when one of the cross-signing secrets is missing locally and in 4S", async () => {
+                    mockCrypto!.getCrossSigningStatus.mockResolvedValue({
+                        publicKeysOnDevice: true,
+                        privateKeysInSecretStorage: false,
+                        privateKeysCachedLocally: {
+                            masterKey: false,
+                            selfSigningKey: true,
+                            userSigningKey: true,
+                        },
+                    });
+
+                    await createAndStart();
+
+                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith("identity_needs_reset");
+                });
+
+                it("shows an out-of-sync toast when the backup key is missing locally", async () => {
+                    mockCrypto!.getSecretStorageStatus.mockResolvedValue(readySecretStorageStatus);
+                    mockCrypto!.getActiveSessionBackupVersion.mockResolvedValue("1");
+                    mockCrypto!.getSessionBackupPrivateKey.mockResolvedValue(null);
+
+                    await createAndStart();
+
+                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith("key_storage_out_of_sync");
+                });
+
+                it("does not show an out-of-sync toast when the backup key is missing locally but backup is purposely disabled", async () => {
+                    mockCrypto!.getSecretStorageStatus.mockResolvedValue(readySecretStorageStatus);
+                    mockCrypto!.getSessionBackupPrivateKey.mockResolvedValue(null);
+                    mockClient.getAccountDataFromServer.mockImplementation((eventType) =>
+                        eventType === BACKUP_DISABLED_ACCOUNT_DATA_KEY ? ({ disabled: true } as any) : null,
                     );
+
+                    await createAndStart();
+
+                    expect(SetupEncryptionToast.hideToast).toHaveBeenCalled();
                 });
 
                 it("hides the out-of-sync toast after we receive the missing secrets", async () => {
@@ -402,9 +436,7 @@ describe("DeviceListener", () => {
 
                     await createAndStart();
 
-                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith(
-                        SetupEncryptionToast.Kind.KEY_STORAGE_OUT_OF_SYNC,
-                    );
+                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith("key_storage_out_of_sync");
 
                     // Then, when we receive the secret, it should be hidden.
                     mockCrypto!.getCrossSigningStatus.mockResolvedValue({
@@ -430,9 +462,7 @@ describe("DeviceListener", () => {
 
                     await createAndStart();
 
-                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith(
-                        SetupEncryptionToast.Kind.SET_UP_RECOVERY,
-                    );
+                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith("set_up_recovery");
                 });
 
                 it("shows an out-of-sync toast when one of the secrets is missing from 4S", async () => {
@@ -446,9 +476,7 @@ describe("DeviceListener", () => {
 
                     await createAndStart();
 
-                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith(
-                        SetupEncryptionToast.Kind.KEY_STORAGE_OUT_OF_SYNC,
-                    );
+                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith("key_storage_out_of_sync");
                 });
             });
         });
@@ -549,9 +577,7 @@ describe("DeviceListener", () => {
                     await createAndStart();
 
                     // Then the toast is displayed
-                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith(
-                        SetupEncryptionToast.Kind.TURN_ON_KEY_STORAGE,
-                    );
+                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith("turn_on_key_storage");
                 });
 
                 it("shows the 'Turn on key storage' toast if we turned on key storage", async () => {
@@ -567,9 +593,7 @@ describe("DeviceListener", () => {
                     await createAndStart();
 
                     // Then the toast is displayed
-                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith(
-                        SetupEncryptionToast.Kind.TURN_ON_KEY_STORAGE,
-                    );
+                    expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith("turn_on_key_storage");
                 });
 
                 it("does not show the 'Turn on key storage' toast if we turned off key storage", async () => {
@@ -582,9 +606,7 @@ describe("DeviceListener", () => {
                     await createAndStart();
 
                     // Then the toast is not displayed
-                    expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith(
-                        SetupEncryptionToast.Kind.TURN_ON_KEY_STORAGE,
-                    );
+                    expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith("turn_on_key_storage");
                 });
             });
 
@@ -602,9 +624,7 @@ describe("DeviceListener", () => {
                     await createAndStart();
 
                     // Then the toast is not displayed
-                    expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith(
-                        SetupEncryptionToast.Kind.TURN_ON_KEY_STORAGE,
-                    );
+                    expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith("turn_on_key_storage");
                 });
 
                 it("does not show the 'Turn on key storage' toast if we turned on key storage", async () => {
@@ -619,9 +639,7 @@ describe("DeviceListener", () => {
                     await createAndStart();
 
                     // Then the toast is not displayed
-                    expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith(
-                        SetupEncryptionToast.Kind.TURN_ON_KEY_STORAGE,
-                    );
+                    expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith("turn_on_key_storage");
                 });
 
                 it("does not show the 'Turn on key storage' toast if we turned off key storage", async () => {
@@ -637,9 +655,7 @@ describe("DeviceListener", () => {
                     await createAndStart();
 
                     // Then the toast is not displayed
-                    expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith(
-                        SetupEncryptionToast.Kind.TURN_ON_KEY_STORAGE,
-                    );
+                    expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith("turn_on_key_storage");
                 });
             });
         });
@@ -1182,25 +1198,21 @@ describe("DeviceListener", () => {
 
                 await createAndStart();
 
-                expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith(SetupEncryptionToast.Kind.SET_UP_RECOVERY);
+                expect(SetupEncryptionToast.showToast).toHaveBeenCalledWith("set_up_recovery");
             });
 
             it("does not show the 'set up recovery' toast if secret storage is set up", async () => {
                 mockCrypto!.getSecretStorageStatus.mockResolvedValue(readySecretStorageStatus);
                 await createAndStart();
 
-                expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith(
-                    SetupEncryptionToast.Kind.SET_UP_RECOVERY,
-                );
+                expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith("set_up_recovery");
             });
 
             it("does not show the 'set up recovery' toast if user has no encrypted rooms", async () => {
                 jest.spyOn(mockClient.getCrypto()!, "isEncryptionEnabledInRoom").mockResolvedValue(false);
                 await createAndStart();
 
-                expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith(
-                    SetupEncryptionToast.Kind.SET_UP_RECOVERY,
-                );
+                expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith("set_up_recovery");
             });
 
             it("does not show the 'set up recovery' toast if the user has chosen to disable key storage", async () => {
@@ -1212,9 +1224,7 @@ describe("DeviceListener", () => {
                 });
                 await createAndStart();
 
-                expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith(
-                    SetupEncryptionToast.Kind.SET_UP_RECOVERY,
-                );
+                expect(SetupEncryptionToast.showToast).not.toHaveBeenCalledWith("set_up_recovery");
             });
         });
     });
