@@ -252,7 +252,7 @@ describe("<SecurityRoomSettingsTab />", () => {
 
             fireEvent.click(screen.getByText("Show advanced"));
 
-            expect(screen.getByLabelText("Enable guest access").getAttribute("aria-checked")).toBe("false");
+            expect(screen.getByLabelText("Enable guest access")).not.toBeChecked();
         });
 
         it("updates guest access on toggle", () => {
@@ -264,7 +264,7 @@ describe("<SecurityRoomSettingsTab />", () => {
             fireEvent.click(screen.getByLabelText("Enable guest access"));
 
             // toggle set immediately
-            expect(screen.getByLabelText("Enable guest access").getAttribute("aria-checked")).toBe("true");
+            expect(screen.getByLabelText("Enable guest access")).toBeChecked();
 
             expect(client.sendStateEvent).toHaveBeenCalledWith(
                 room.roomId,
@@ -285,14 +285,14 @@ describe("<SecurityRoomSettingsTab />", () => {
             fireEvent.click(screen.getByLabelText("Enable guest access"));
 
             // toggle set immediately
-            expect(screen.getByLabelText("Enable guest access").getAttribute("aria-checked")).toBe("false");
+            expect(screen.getByLabelText("Enable guest access")).not.toBeChecked();
 
             await flushPromises();
             expect(client.sendStateEvent).toHaveBeenCalled();
             expect(logger.error).toHaveBeenCalledWith("oups");
 
             // toggle reset to old value
-            expect(screen.getByLabelText("Enable guest access").getAttribute("aria-checked")).toBe("true");
+            expect(screen.getByLabelText("Enable guest access")).toBeChecked();
         });
     });
 
@@ -377,6 +377,76 @@ describe("<SecurityRoomSettingsTab />", () => {
             expect(screen.getByDisplayValue(HistoryVisibility.Shared)).toBeChecked();
             expect(logger.error).toHaveBeenCalledWith("oups");
         });
+
+        it("maps 'joined' history visibility to 'invited' for display", () => {
+            const room = new Room(roomId, client, userId);
+            setRoomStateEvents(room, undefined, undefined, HistoryVisibility.Joined);
+
+            getComponent(room);
+
+            // Should display as 'invited' even though underlying value is 'joined'
+            expect(screen.getByDisplayValue(HistoryVisibility.Invited)).toBeChecked();
+            // Should not have a 'joined' option visible
+            expect(screen.queryByDisplayValue(HistoryVisibility.Joined)).not.toBeInTheDocument();
+        });
+
+        it("shows 'invited' option for non-public rooms", () => {
+            const room = new Room(roomId, client, userId);
+            setRoomStateEvents(room, JoinRule.Invite);
+
+            getComponent(room);
+
+            expect(screen.getByDisplayValue(HistoryVisibility.Invited)).toBeInTheDocument();
+        });
+
+        it("shows 'invited' option for encrypted rooms even if public", async () => {
+            const room = new Room(roomId, client, userId);
+            jest.spyOn(client.getCrypto()!, "isEncryptionEnabledInRoom").mockResolvedValue(true);
+            setRoomStateEvents(room, JoinRule.Public);
+
+            getComponent(room);
+
+            await waitFor(() => expect(screen.getByDisplayValue(HistoryVisibility.Invited)).toBeInTheDocument());
+        });
+
+        it("does not show 'invited' option for public unencrypted rooms unless selected", async () => {
+            const room = new Room(roomId, client, userId);
+            setRoomStateEvents(room, JoinRule.Public, undefined, HistoryVisibility.Shared);
+
+            getComponent(room);
+
+            await waitFor(() => expect(screen.queryByDisplayValue(HistoryVisibility.Invited)).not.toBeInTheDocument());
+        });
+
+        it("shows 'world_readable' option for public unencrypted rooms", async () => {
+            const room = new Room(roomId, client, userId);
+            setRoomStateEvents(room, JoinRule.Public);
+
+            getComponent(room);
+
+            await waitFor(() => expect(screen.getByDisplayValue(HistoryVisibility.WorldReadable)).toBeInTheDocument());
+        });
+
+        it("does not show 'world_readable' option for private encrypted rooms unless selected", async () => {
+            const room = new Room(roomId, client, userId);
+            jest.spyOn(client.getCrypto()!, "isEncryptionEnabledInRoom").mockResolvedValue(true);
+            setRoomStateEvents(room, JoinRule.Invite);
+
+            getComponent(room);
+
+            await waitFor(() =>
+                expect(screen.queryByDisplayValue(HistoryVisibility.WorldReadable)).not.toBeInTheDocument(),
+            );
+        });
+
+        it("always shows 'shared' option", () => {
+            const room = new Room(roomId, client, userId);
+            setRoomStateEvents(room);
+
+            getComponent(room);
+
+            expect(screen.getByDisplayValue(HistoryVisibility.Shared)).toBeInTheDocument();
+        });
     });
 
     describe("encryption", () => {
@@ -388,7 +458,7 @@ describe("<SecurityRoomSettingsTab />", () => {
 
             await waitFor(() => expect(screen.getByLabelText("Encrypted")).toBeChecked());
             // can't disable encryption once enabled
-            expect(screen.getByLabelText("Encrypted").getAttribute("aria-disabled")).toEqual("true");
+            expect(screen.getByLabelText("Encrypted")).toBeDisabled();
         });
 
         it("asks users to confirm when setting room to encrypted", async () => {
@@ -495,7 +565,7 @@ describe("<SecurityRoomSettingsTab />", () => {
                 getComponent(room);
 
                 await waitFor(() => expect(screen.getByLabelText("Encrypted")).toBeChecked());
-                expect(screen.getByLabelText("Encrypted").getAttribute("aria-disabled")).toEqual("true");
+                expect(screen.getByLabelText("Encrypted")).toBeDisabled();
                 expect(screen.getByText("Once enabled, encryption cannot be disabled.")).toBeInTheDocument();
             });
 
@@ -505,7 +575,7 @@ describe("<SecurityRoomSettingsTab />", () => {
                 getComponent(room);
 
                 await waitFor(() => expect(screen.getByLabelText("Encrypted")).not.toBeChecked());
-                expect(screen.getByLabelText("Encrypted").getAttribute("aria-disabled")).toEqual("true");
+                expect(screen.getByLabelText("Encrypted")).toBeDisabled();
                 expect(screen.queryByText("Once enabled, encryption cannot be disabled.")).not.toBeInTheDocument();
                 expect(screen.getByText("Your server requires encryption to be disabled.")).toBeInTheDocument();
             });
